# PreviewStartDatePolicy

The options on how the preview start date is calculated. - If you set this field to `startOfTerm`, the preview start date is the start date of the subscription term.    - If you set this field to `today`, the preview start date is today. - If you set this field to `specificDate`, you must specify a specific date in the `specificDate` field. The date must be in the format `yyyy-mm-dd`. 

## Enum

* `STARTOFTERM` (value: `'startOfTerm'`)

* `TODAY` (value: `'today'`)

* `SPECIFICDATE` (value: `'specificDate'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


